@@ -67,6 +67,8 @@ class ClientInfo;
 class ClientList;
 class ConnectionList;
 class ConnectionManager;
+class DhtManager;
+class DhtRouter;
 class Download;
 class DownloadMain;
 class DownloadWrapper;
@@ -90,8 +92,8 @@ class Poll;
 class ProtocolExtension;
 class Rate;
 class SocketSet;
+class Throttle;
 class Tracker;
-class TrackerBase;
 class TrackerList;
 class TrackerManager;
 class TransferList;
