@@ -51,7 +51,8 @@ public:
   static const int flag_active             = (1 << 0);
   static const int flag_create_queued      = (1 << 1);
   static const int flag_resize_queued      = (1 << 2);
-  static const int flag_previously_created = (1 << 3);
+  static const int flag_fallocate          = (1 << 3);
+  static const int flag_previously_created = (1 << 4);
 
   File();
   ~File();
@@ -162,12 +163,12 @@ File::is_valid_position(uint64_t p) const {
 
 inline void
 File::set_flags(int flags) {
-  set_flags_protected(flags & (flag_create_queued | flag_resize_queued));
+  set_flags_protected(flags & (flag_create_queued | flag_resize_queued | flag_fallocate));
 }
 
 inline void
 File::unset_flags(int flags) {
-  unset_flags_protected(flags & (flag_create_queued | flag_resize_queued));
+  unset_flags_protected(flags & (flag_create_queued | flag_resize_queued | flag_fallocate));
 }
 
 inline void
